==> openturns_0.12.2.orig.tar.gz: openturns-0.12.2/lib/test/t_SymmetricMatrixLapack_std.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_SymmetricMatrixLapack_std.cxx
 *  @brief The test file for the Lapack based methods of the SquareMatrix class
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-10-31 11:52:04 +0100 (ven 31 oct 2008) $
 *  Id:      $Id: t_SymmetricMatrixLapack_std.cxx 995 2008-10-31 10:52:04Z dutka $
 */
#include <iostream>
#include "OT.hxx"
#include "OTtestcode.hxx"
#include <cmath>
#include "SymmetricMatrix.hxx"
#include "NumericalPoint.hxx"

using namespace OT;
using namespace OT::Test;
using namespace OT::Base::Type;

int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  
  SymmetricMatrix matrix1(2);
  matrix1.setName("matrix1");
  matrix1(0,0)=1. ;
  matrix1(0,1)=5. ;
  matrix1(1,0)=5. ;
  matrix1(1,1)=12. ;
  std::cout << "matrix1 = " << matrix1 << std::endl;
  
  NumericalPoint pt ;
  pt.add(5.) ;
  pt.add(0.) ;
  std::cout << "pt = " << pt << std::endl;
  
  NumericalPoint result ;
  result = matrix1.solveLinearSystem(pt);
  std::cout << "result = " << result << std::endl;
  
  NumericalScalar determinant ;
  determinant = matrix1.computeDeterminant();
  std::cout << "determinant = " << determinant << std::endl;
  
  Collection<NumericalScalar> ev(2);
  ev = matrix1.computeEigenValues().getCollection();
  std::cout << "ev = " << ev << std::endl;

  return ExitCode::Success;
}

==> openturns_0.13.1.orig.tar.gz: openturns-0.13.1/lib/test/t_SymmetricMatrixLapack_std.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_SymmetricMatrixLapack_std.cxx
 *  @brief The test file for the Lapack based methods of the SquareMatrix class
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2009-05-28 14:47:53 +0200 (jeu. 28 mai 2009) $
 *  Id:      $Id: t_SymmetricMatrixLapack_std.cxx 1262 2009-05-28 12:47:53Z dutka $
 */
#include <iostream>
#include "OT.hxx"
#include "OTtestcode.hxx"
#include "OStream.hxx"
#include <cmath>
#include "SymmetricMatrix.hxx"
#include "NumericalPoint.hxx"

using namespace OT;
using namespace OT::Test;
using namespace OT::Base::Common;
using namespace OT::Base::Type;

int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);
  
  SymmetricMatrix matrix1(2);
  matrix1.setName("matrix1");
  matrix1(0,0)=1. ;
  matrix1(0,1)=5. ;
  matrix1(1,0)=5. ;
  matrix1(1,1)=12. ;
  fullprint << "matrix1 = " << matrix1 << std::endl;
  
  NumericalPoint pt ;
  pt.add(5.) ;
  pt.add(0.) ;
  fullprint << "pt = " << pt << std::endl;
  
  NumericalPoint result ;
  result = matrix1.solveLinearSystem(pt);
  fullprint << "result = " << result << std::endl;
  
  NumericalScalar determinant ;
  determinant = matrix1.computeDeterminant();
  fullprint << "determinant = " << determinant << std::endl;
  
  Collection<NumericalScalar> ev(2);
  ev = matrix1.computeEigenValues().getCollection();
  fullprint << "ev = " << ev << std::endl;

  return ExitCode::Success;
}
